package speaker;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import NTPortJava.*;
import java.awt.Dimension;
import java.awt.Rectangle;

/**
 * <p>Title: Speaker Sample</p>
 * <p>Description: This sample illustrates how to use NTPort Library to control PC speaker.</p>
 * <p>Copyright: Copyright (c) 2004-2006 Zeal SoftStudio</p>
 * <p>Company: Zeal SoftStudio</p>
 * @author Hai Li
 * @version 1.0
 */

public class Frame1
    extends JFrame {
  JPanel contentPane;
  JLabel jLabel1 = new JLabel();
  JTextField jTextField1 = new JTextField();
  JButton jButton1 = new JButton();
  JButton jButton2 = new JButton();
  JLabel jLabel2 = new JLabel();
  JLabel jLabel3 = new JLabel();

  //Construct the frame
  public Frame1() {
    // After register NTPort Library,
    // place your registration information here.
    NTPortJava.LicenseInfo("Your Name", 0);

    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }

  //Component initialization
  private void jbInit() throws Exception {
    contentPane = (JPanel)this.getContentPane();
    jLabel1.setText("Freqency(Hz):");
    jLabel1.setBounds(new Rectangle(10, 11, 70, 15));
    contentPane.setLayout(null);
    this.setSize(new Dimension(375, 116));
    this.setContentPane(contentPane);
    this.setTitle("Speaker Sample");
    this.addContainerListener(new Frame1_this_containerAdapter(this));
    jTextField1.setText("262");
    jTextField1.setBounds(new Rectangle(90, 8, 48, 21));
    jButton1.setBounds(new Rectangle(151, 7, 92, 25));
    jButton1.setText("Sound On");
    jButton1.addActionListener(new Frame1_jButton1_actionAdapter(this));
    jButton2.setBounds(new Rectangle(267, 7, 92, 25));
    jButton2.setText("Sound Off");
    jButton2.addActionListener(new Frame1_jButton2_actionAdapter(this));
    jLabel2.setHorizontalAlignment(SwingConstants.LEFT);
    jLabel2.setHorizontalTextPosition(SwingConstants.CENTER);
    jLabel2.setText("Click \"Sound On\" to start.");
    jLabel2.setVerticalAlignment(SwingConstants.CENTER);
    jLabel2.setVerticalTextPosition(SwingConstants.CENTER);
    jLabel2.setBounds(new Rectangle(10, 31, 304, 15));
    jLabel3.setToolTipText("");
    jLabel3.setText("Copyright (c) 1997-2006 Zeal SoftStudio. www.zealsoft.com");
    jLabel3.setBounds(new Rectangle(10, 54, 361, 15));
    contentPane.add(jLabel1, null);
    contentPane.add(jTextField1, null);
    contentPane.add(jLabel2, null);
    contentPane.add(jButton1, null);
    contentPane.add(jLabel3, null);
    contentPane.add(jButton2, null);
  }

  //Overridden so we can exit when window is closed
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      System.exit(0);
    }
  }

  private void Speaker(boolean bOn) {
    short nValue;
    StringBuffer s = new StringBuffer(255);

    nValue = NTPortJava.Inport( (short) 0x61);
    if (bOn) {
      nValue |= (short) 3;
      nValue = 0x2F;

      // Get the state returned from NTPort Library
      NTPortJava.GetLastState(s);
      jLabel2.setText("Result: " + s.toString());
    }
    else {
      nValue &= ~3;
    }
    NTPortJava.Outport( (short) 0x61, nValue);
  }

  // Speaker freq is set by setting divider in Intel
  // 8253/8254 timer chip at port addresses 0x42 through 0x43
  private void SetFreq(int nFreq) {
    final int Clk8253 = 1193180;
    short nDivider;

    if (nFreq != 0) {
      nDivider = (short) (Clk8253 / nFreq);
      NTPortJava.Outport( (short) 0x43, (short) 0xb6); // timer 2, square wave
      NTPortJava.Outport( (short) 0x42, (short) (nDivider % 256));
      NTPortJava.Outport( (short) 0x42, (short) (nDivider / 256));
      Speaker(true);
    }
    else {
      Speaker(false);
    }
  }

  void jButton1_actionPerformed(ActionEvent e) {
    SetFreq(Integer.valueOf(jTextField1.getText()).intValue());
  }

  void jButton2_actionPerformed(ActionEvent e) {
    Speaker(false);
  }

}  //  @jve:decl-index=0:visual-constraint="10,10"

class Frame1_jButton1_actionAdapter
    implements java.awt.event.ActionListener {
  Frame1 adaptee;

  Frame1_jButton1_actionAdapter(Frame1 adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jButton1_actionPerformed(e);
  }
}

class Frame1_jButton2_actionAdapter
    implements java.awt.event.ActionListener {
  Frame1 adaptee;

  Frame1_jButton2_actionAdapter(Frame1 adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jButton2_actionPerformed(e);
  }
}

class Frame1_this_containerAdapter
    extends java.awt.event.ContainerAdapter {
  Frame1 adaptee;

  Frame1_this_containerAdapter(Frame1 adaptee) {
    this.adaptee = adaptee;
  }

}